#!/usr/bin/env python
# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
from __future__ import (unicode_literals, division, absolute_import,
                        print_function)

__license__   = 'GPL v3'
__copyright__ = '2011, Grant Drake <grant.drake@gmail.com>'
__docformat__ = 'restructuredtext en'

from collections import OrderedDict
from PyQt5.Qt import QWidget, QGridLayout, QLabel, QPushButton, QGroupBox, QVBoxLayout
from calibre.utils.config import JSONConfig

from calibre_plugins.norm_comment.common_utils import KeyValueComboBox, KeyboardConfigDialog, ImageTitleLayout

load_translations()

STORE_NAME = 'Options'
KEY_ITALIC_TO_ASTERISK  = 'italicToAsterisk'
KEY_BOLD_TO_ASTERISK = 'boldToAsterisk'
KEY_KEEP_LINK_URL = 'keepLinkUrl'

SHOW_ITALIC = OrderedDict([('keep', _('Use asterisk to indicate emphasis  --  *text in italic*')),
                        ('none', _('No markers  --  text in italic'))])

SHOW_BOLD = OrderedDict([('keep', _('Use asterisks to indicate emphasis  --  **text in bold**')),
                        ('none', _('No markers  --  text in bold'))])

SHOW_URL = OrderedDict([('keep', _('Keep URL  --  [Link text](Link URL)')),
                        ('none', _('Delete URL  --  Link text'))])

DEFAULT_STORE_VALUES = {
    KEY_ITALIC_TO_ASTERISK: 'keep',
    KEY_BOLD_TO_ASTERISK: 'keep',
    KEY_KEEP_LINK_URL: 'keep',
}

# This is where all preferences for this plugin will be stored
plugin_prefs = JSONConfig('plugins/NormComment')

# Set defaults
plugin_prefs.defaults[STORE_NAME] = DEFAULT_STORE_VALUES

class ConfigWidget(QWidget):

    def __init__(self, plugin_action):
        QWidget.__init__(self)
        self.plugin_action = plugin_action
        layout = QVBoxLayout(self)
        self.setLayout(layout)

        c = plugin_prefs[STORE_NAME]
		
        title_layout = ImageTitleLayout(self, 'images/tools.png', _('Cleaning comments Options'))
        layout.addLayout(title_layout)
		
		# --- Markdown options ---
        markdown_group_box = QGroupBox(_('Markdown Options:'), self)
        layout.addWidget(markdown_group_box)
        markdown_group_box_layout = QGridLayout()
        markdown_group_box.setLayout(markdown_group_box_layout)
		
		markdown_group_box_layout.addWidget(QLabel(_("By default the plugin transform HTML text to Markdown. You can adjust the output bellow.")), 0, 1)
		
        markdown_group_box_layout.addWidget(QLabel(_("<p>Text in <i>italic</i>:</p>"), self), 1, 1)
        post_show1 = c.get(KEY_ITALIC_TO_ASTERISK, DEFAULT_STORE_VALUES[KEY_ITALIC_TO_ASTERISK])
        self.showCombo1 = KeyValueComboBox(self, SHOW_ITALIC, post_show1)
        markdown_group_box_layout.addWidget(self.showCombo1, 2, 1)

        markdown_group_box_layout.addWidget(QLabel(_('<p>Text in <b>bold</b>:</p>'), self), 3, 1)
        post_show2 = c.get(KEY_BOLD_TO_ASTERISK, DEFAULT_STORE_VALUES[KEY_BOLD_TO_ASTERISK])
        self.showCombo2 = KeyValueComboBox(self, SHOW_BOLD, post_show2)
        markdown_group_box_layout.addWidget(self.showCombo2, 4, 1)

        markdown_group_box_layout.addWidget(QLabel(_('Link URL:'), self), 5, 1)
        post_show3 = c.get(KEY_KEEP_LINK_URL, DEFAULT_STORE_VALUES[KEY_KEEP_LINK_URL])
        self.showCombo3 = KeyValueComboBox(self, SHOW_URL, post_show3)
        markdown_group_box_layout.addWidget(self.showCombo3, 6, 1)

        keyboard_shortcuts_button = QPushButton(_('Keyboard shortcuts...'), self)
        keyboard_shortcuts_button.setToolTip(_(
                    'Edit the keyboard shortcuts associated with this plugin'))
        keyboard_shortcuts_button.clicked.connect(self.edit_shortcuts)
        layout.addWidget(keyboard_shortcuts_button)
        layout.addStretch(1)

    def save_settings(self):
        new_prefs = {}
        new_prefs[KEY_ITALIC_TO_ASTERISK] = self.showCombo1.selected_key()
        new_prefs[KEY_BOLD_TO_ASTERISK] = self.showCombo2.selected_key()
        new_prefs[KEY_KEEP_LINK_URL] = self.showCombo3.selected_key()

        plugin_prefs[STORE_NAME] = new_prefs

    def edit_shortcuts(self):
        d = KeyboardConfigDialog(self.plugin_action.gui, self.plugin_action.action_spec[0])
        if d.exec_() == d.Accepted:
            self.plugin_action.gui.keyboard.finalize()
